@@ -61,3 +61,5 @@ def notejob():
         job.stop()
     elif args.command == 'restart':
         job.restart()
+    else:
+        logger.info("unknown")
